==> ade-8.5.4-en-download.zip: ade-8.5.4-en/webhelp/ade-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database adabasdeltasave
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var adabasdeltasave = {
    baseurls: ["../"],
    varname: "adabasdeltasave",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "install/adeinst.htm", title: "Adabas Delta Save Facility Installation",
              tree: [
                  { url: "install/sysreq.htm", title: "System Requirements" },
                  { url: "install/adeiinst.htm", title: "Installation Procedure" },
                  { url: "install/adeisft.htm", title: "Sequential File Table" },
                  { url: "install/adeifix.htm", title: "Applying Fixes to Delta Save" },
              ]
            },
            { url: "relnotes/relnotes.htm", title: "Release Notes",
              tree: [
                  { url: "relnotes/enh.htm", title: "Enhancements" },
                  { url: "relnotes/dscompat.htm", title: "Combining Delta Save Tapes from Different Versions" },
                  { url: "relnotes/eom.htm", title: "End of Maintenance" },
                  { url: "relnotes/doc.htm", title: "Documentation and Other Online Information" },
              ]
            },
            { url: "concepts/adeintr.htm", title: "Introducing Adabas Delta Save Facility" },
            { url: "admin/adeadmin.htm", title: "Adabas Delta Save Facility Administration",
              tree: [
                  { url: "admin/adeaov.htm", title: "Overview" },
                  { url: "admin/adedsf.htm", title: "ADARUN Parameter DSF" },
                  { url: "admin/adedsfex.htm", title: "ADARUN Parameter DSFEX1" },
                  { url: "admin/adeonfx.htm", title: "Special Online Functions" },
                  { url: "admin/adedlog.htm", title: "Calculating the DLOG Area Size" },
                  { url: "admin/adedsim.htm", title: "Calculating the DSIM Data Set Size" },
              ]
            },
            { url: "util/ade_util.htm", title: "Adabas Utility Functions for Delta Save",
              tree: [
                  { url: "util/adefx.htm", title: "Adabas Utility Functions for the Adabas Delta Save Facility" },
                  { url: "util/adafrm.htm", title: "ADAFRM Utility",
                    tree: [
                        { url: "util/adafrmjc.htm", title: "ADAFRM JCL/JCS Requirements and Examples" },
                    ]
                  },
                  { url: "util/adapri.htm", title: "ADAPRI Utility" },
                  { url: "util/adarep.htm", title: "ADAREP Utility" },
                  { url: "util/adares.htm", title: "ADARES Utility",
                    tree: [
                        { url: "util/adaresjc.htm", title: "ADARES JCL/JCS Requirements and Examples" },
                    ]
                  },
                  { url: "util/adasav.htm", title: "ADASAV Utility",
                    tree: [
                        { url: "util/adasavmr.htm", title: "ADASAV MERGE" },
                        { url: "util/adasavrs.htm", title: "ADASAV RESTORE DELTA: Restore Without Prior Merging" },
                        { url: "util/adasavsv.htm", title: "ADASAV SAVE: Save Database" },
                        { url: "util/adasavsd.htm", title: "ADASAV SAVE DELTA: Save Changed Database Blocks" },
                        { url: "util/adasavre.htm", title: "Restarting an Interrupted Save Operation" },
                        { url: "util/adasavrj.htm", title: "ADASAV JCL/JCS Requirements and Examples" },
                    ]
                  },
                  { url: "util/adauld.htm", title: "ADAULD Utility",
                    tree: [
                        { url: "util/adauldjc.htm", title: "ADAULD JCL/JCS Requirements and Examples" },
                    ]
                  },
              ]
            },
            { url: "general/glossary.htm", title: "Glossary" },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: adabasdeltasave });

==> ade-8.6.1-en-download.zip: ade-8.6.1-en/webhelp/ade-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database adabasdeltasave
//
//	Copyright (c) 2016-2025 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var adabasdeltasave = {
    baseurls: ["../"],
    varname: "adabasdeltasave",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "install/adeinst.htm", title: "Adabas Delta Save Facility Installation",
              tree: [
                  { url: "install/sysreq.htm", title: "System Requirements" },
                  { url: "install/adeiinst.htm", title: "Installation Procedure" },
                  { url: "install/adeisft.htm", title: "Sequential File Table" },
                  { url: "install/adeifix.htm", title: "Applying Fixes to Delta Save" },
              ]
            },
            { url: "relnotes/relnotes.htm", title: "Release Notes",
              tree: [
                  { url: "relnotes/enh.htm", title: "Enhancements" },
                  { url: "relnotes/req.htm", title: "Adabas Requirements" },
                  { url: "relnotes/dscompat.htm", title: "Combining Delta Save Tapes from Different Versions" },
                  { url: "relnotes/eom.htm", title: "End of Maintenance" },
                  { url: "relnotes/doc.htm", title: "Documentation and Other Online Information" },
              ]
            },
            { url: "concepts/adeintr.htm", title: "Introducing Adabas Delta Save Facility" },
            { url: "admin/adeadmin.htm", title: "Adabas Delta Save Facility Administration",
              tree: [
                  { url: "admin/adeaov.htm", title: "Overview" },
                  { url: "admin/adedsf.htm", title: "ADARUN Parameter DSF" },
                  { url: "admin/adedsfex.htm", title: "ADARUN Parameter DSFEX1" },
                  { url: "admin/adeonfx.htm", title: "Special Online Functions" },
                  { url: "admin/adedlog.htm", title: "Calculating the DLOG Area Size" },
                  { url: "admin/adedsim.htm", title: "Calculating the DSIM Data Set Size" },
              ]
            },
            { url: "util/ade_util.htm", title: "Adabas Utility Functions for Delta Save",
              tree: [
                  { url: "util/adefx.htm", title: "Adabas Utility Functions for the Adabas Delta Save Facility" },
                  { url: "util/adafrm.htm", title: "ADAFRM Utility",
                    tree: [
                        { url: "util/adafrmjc.htm", title: "ADAFRM JCL Requirements and Examples" },
                        { url: "util/adachk.htm", title: "ADACHK Utility" },
                    ]
                  },
                  { url: "util/adarep.htm", title: "ADAREP Utility" },
                  { url: "util/adares.htm", title: "ADARES Utility",
                    tree: [
                        { url: "util/adaresjc.htm", title: "ADARES JCL Requirements and Examples" },
                    ]
                  },
                  { url: "util/adasav.htm", title: "ADASAV Utility",
                    tree: [
                        { url: "util/adasavmr.htm", title: "ADASAV MERGE" },
                        { url: "util/adasavrs.htm", title: "ADASAV RESTORE DELTA: Restore Without Prior Merging" },
                        { url: "util/adasavsv.htm", title: "ADASAV SAVE: Save Database" },
                        { url: "util/adasavsd.htm", title: "ADASAV SAVE DELTA: Save Changed Database Blocks" },
                        { url: "util/adasavre.htm", title: "Restarting an Interrupted Save Operation" },
                        { url: "util/adasavrj.htm", title: "ADASAV JCL Requirements and Examples" },
                    ]
                  },
                  { url: "util/adauld.htm", title: "ADAULD Utility",
                    tree: [
                        { url: "util/adauldjc.htm", title: "ADAULD JCL Requirements and Examples" },
                    ]
                  },
              ]
            },
            { url: "general/glossary.htm", title: "Glossary" },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: adabasdeltasave });
